@@ -42,11 +42,12 @@
 
 class CustomTitle : public KTitleWidget
 {
+    Q_OBJECT
 public:
     explicit CustomTitle(QWidget *parent = nullptr);
 
 protected:
-    bool event(QEvent *event) override;
+    void changeEvent(QEvent *event) override;
     void paintEvent(QPaintEvent *event) override;
     void colorsChanged();
 };
@@ -66,20 +67,20 @@ CustomTitle::CustomTitle(QWidget *parent)
     colorsChanged();
 }
 
-bool CustomTitle::event(QEvent *event)
+void CustomTitle::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::ApplicationPaletteChange || event->type() == QEvent::PaletteChange) {
-        this->colorsChanged();
+    if (event->type() == QEvent::PaletteChange) {
+        colorsChanged();
+        return; // deliberately intercept
     }
-    return QWidget::event(event);
+    return KTitleWidget::changeEvent(event);
 }
 
 void CustomTitle::colorsChanged()
 {
-    auto config = KSharedConfig::openConfig();
-    auto active = KColorScheme(QPalette::Active, KColorScheme::Header, config);
-    auto inactive = KColorScheme(QPalette::Inactive, KColorScheme::Header, config);
-    auto disabled = KColorScheme(QPalette::Disabled, KColorScheme::Header, config);
+    auto active = KColorScheme(QPalette::Active, KColorScheme::Header);
+    auto inactive = KColorScheme(QPalette::Inactive, KColorScheme::Header);
+    auto disabled = KColorScheme(QPalette::Disabled, KColorScheme::Header);
 
     QPalette palette = QWidget::palette();
 
@@ -217,6 +218,7 @@ ModuleView::ModuleView(const std::shared_ptr<QQmlEngine> &engine, QWidget *paren
 
 ModuleView::~ModuleView()
 {
+    closeModules();
     delete d;
 }
 
@@ -286,6 +288,7 @@ void ModuleView::addModule(MenuItem *item, const QStringList &args)
         kcm->widget()->setAutoFillBackground(false);
         kcm->load();
         connect(kcm, &KCModule::needsSaveChanged, this, &ModuleView::stateChanged);
+        connect(kcm, &KCModule::buttonsChanged, this, &ModuleView::updateButtons);
         connect(kcm, &KCModule::representsDefaultsChanged, this, [this, kcm]() {
             if (kcm == d->mPages.value(d->mPageWidget->currentPage()) && kcm->buttons() & d->mButtonMask & KCModule::Default) {
                 d->mDefault->setEnabled(!kcm->representsDefaults());
@@ -696,3 +699,5 @@ bool ModuleView::eventFilter(QObject *watched, QEvent *event)
 }
 
 #include "moc_ModuleView.cpp"
+#include "ModuleView.moc"
+
